pub struct FuncInit {
pub admin: Pubkey,
pub functions: Pubkey,
pub f: Pubkey,
pub system_program: Pubkey,
}Expand description
Generated client accounts for FuncInit.
Fields
admin: Pubkeyfunctions: Pubkeyf: Pubkeysystem_program: PubkeyTrait Implementations
Sourceimpl BorshSerialize for FuncInitwhere
Pubkey: BorshSerialize,
impl BorshSerialize for FuncInitwhere
Pubkey: BorshSerialize,
Sourceimpl ToAccountMetas for FuncInit
impl ToAccountMetas for FuncInit
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for FuncInit
impl RefUnwindSafe for FuncInit
impl Send for FuncInit
impl Sync for FuncInit
impl Unpin for FuncInit
impl UnwindSafe for FuncInit