pub struct Functions {Show 17 fields
pub admin: Pubkey,
pub initialized: bool,
pub exp: Pubkey,
pub ln: Pubkey,
pub log10: Pubkey,
pub sin: Pubkey,
pub cos: Pubkey,
pub padding_0: Pubkey,
pub padding_1: Pubkey,
pub padding_2: Pubkey,
pub padding_3: Pubkey,
pub padding_4: Pubkey,
pub padding_5: Pubkey,
pub padding_6: Pubkey,
pub padding_7: Pubkey,
pub padding_8: Pubkey,
pub padding_9: Pubkey,
}Fields
admin: Pubkeyinitialized: boolexp: Pubkeyln: Pubkeylog10: Pubkeysin: Pubkeycos: Pubkeypadding_0: Pubkeypadding_1: Pubkeypadding_2: Pubkeypadding_3: Pubkeypadding_4: Pubkeypadding_5: Pubkeypadding_6: Pubkeypadding_7: Pubkeypadding_8: Pubkeypadding_9: PubkeyTrait Implementations
Sourceimpl AccountDeserialize for Functions
impl AccountDeserialize for Functions
Sourcefn try_deserialize(buf: &mut &[u8]) -> Result<Self>
fn try_deserialize(buf: &mut &[u8]) -> Result<Self>
Deserializes previously initialized account data. Should fail for all
uninitialized accounts, where the bytes are zeroed. Implementations
should be unique to a particular account type so that one can never
successfully deserialize the data of one account type into another.
For example, if the SPL token program were to implement this trait,
it should be impossible to deserialize a
Mint account into a token
Account.Sourcefn try_deserialize_unchecked(buf: &mut &[u8]) -> Result<Self>
fn try_deserialize_unchecked(buf: &mut &[u8]) -> Result<Self>
Deserializes account data without checking the account discriminator.
This should only be used on account initialization, when the bytes of
the account are zeroed.
Sourceimpl AccountSerialize for Functions
impl AccountSerialize for Functions
Sourceimpl BorshDeserialize for Functions
impl BorshDeserialize for Functions
Sourceimpl BorshSerialize for Functions
impl BorshSerialize for Functions
Sourceimpl Discriminator for Functions
impl Discriminator for Functions
const DISCRIMINATOR: [u8; 8]
fn discriminator() -> [u8; 8]